Changelog
---------

Unreleased
~~~~~~~~~~

0.2.0 (2015-10-12)
~~~~~~~~~~~~~~~~~~~

- Removes Python 2.x support.
  [href]

0.1.2 (2015-08-28)
~~~~~~~~~~~~~~~~~~~

- Moved most code out to onegov.core for similar modules to use.
  [href]

0.1.1 (2015-06-26)
~~~~~~~~~~~~~~~~~~~

- Adds support for onegov.core.upgrade
  [href]

- Remove support for Python 3.3.
  [href]

0.1.0 (2015-05-07)
~~~~~~~~~~~~~~~~~~~

- Adds a page type column which may be used for polymorphic identites.
  [href]

0.0.1 (2015-04-29)
~~~~~~~~~~~~~~~~~~~

- Initial Release [href]
